==> haskell-free-5.1-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1
id: free-5.1-H74Rsn8sD972h09VRi6oJn
key: free-5.1-H74Rsn8sD972h09VRi6oJn
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: 79e9a4d635bdb831a08cf9897a51a0c7
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/free-5.1
hs-libraries: HSfree-5.1-H74Rsn8sD972h09VRi6oJn
includes:
    free-common.h
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    distributive-0.6-EFya3V3cIox45Or0Qg9qsO mtl-2.2.2
    profunctors-5.3-FeDuHDGI4bOCxClca48Fbi
    semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    template-haskell-2.13.0.0 exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             distributive-0.6-EFya3V3cIox45Or0Qg9qsO=3a199d7caacf8c6f1ba526ec880fea86
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.3-FeDuHDGI4bOCxClca48Fbi=b6c03e8ca3a4111776a405a0612a8055
             semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx=66c322814c5a6541c0713134ceca4e93
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.1
id: free-5.1-HBkqjGoz8WgDKVtCe8zPGF
key: free-5.1-HBkqjGoz8WgDKVtCe8zPGF
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: a74de1f5810b2bd1af0bdcd2ea364e6b
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.6.1/site-local/free-5.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/free-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/free-5.1
hs-libraries: HSfree-5.1-HBkqjGoz8WgDKVtCe8zPGF
includes:
    free-common.h
depends:
    base-4.12.0.0 comonad-5.0.4-HRLmz868PXZ5L5mXj8jipp
    containers-0.6.0.1 distributive-0.6-DtS7Cohs8dm4iMWvChMD9B
    exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1 mtl-2.2.2
    profunctors-5.3-8jSlhTxWDNkEHiRDjiAQ7G
    semigroupoids-5.3.1-6XYi8Zh0RJZGpeabZDZF5r
    template-haskell-2.14.0.0 transformers-0.5.5.0
    transformers-base-0.4.5.2-IrU9RLUyNmJ8YkbNrC8RMj
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
